SET LOCAL yb_non_ddl_txn_for_sys_tables_allowed TO true;

-- This migration is due to an ICU version upgrade from 67.1 to 70.1. After upgrading,
-- 3 collations appear to be removed as they are not added after initdb/reinitb.
-- This would cause issues for anybody using these deleted collations, but the risk of that
-- happening is very low since collations are a new feature. Ultimately, We are relying on
-- nobody using it since it was introduced just recently and we don't want to delay the upgrade.
DO $$
  DECLARE pg_version VARCHAR;
  DECLARE platform VARCHAR;
  DECLARE en_us_utf8 VARCHAR;
  DECLARE ucs_basic_oid INTEGER;
  DECLARE pg_collation_count INTEGER;
BEGIN
  -- The collation "en_US.utf8" on Linux is called "en_US.UTF-8" on Mac OS.
  SELECT version() into pg_version;
  platform = substr(pg_version, strpos(pg_version, ' on ') + 3);
  platform = substr(platform, 1, strpos(platform, ', compiled by') - 1);
  IF platform LIKE '%linux%' THEN
    en_us_utf8 = 'en_US.utf8';
  ELSIF platform LIKE '%apple%' THEN
    en_us_utf8 = 'en_US.UTF-8';
  ELSE
    RAISE EXCEPTION 'unknown platform %', platform;
  END IF;

  -- Instead of loading collations via pg_import_system_collations, we use PL/pgSQL to
  -- improve performance by doing direct inserts.
  IF NOT EXISTS (
    -- doi-x-icu is one of the new collations introduced, so use that for idempotency.
    SELECT FROM pg_catalog.pg_collation
      WHERE collname = 'doi-x-icu' AND collencoding = -1 AND collnamespace = 11
  ) THEN
    -- Need to delete some old descriptions from pg_description and collations from pg_collation
    -- that are no longer supported in ICU version 70.
    -- nds-x-icu, nds-DE-x-icu, nds-NL-x-icu are gone entirely, but mi-x-icu and mi-NZ-x-icu
    -- only have their descriptions removed.
    WITH descr_delete_oids(pg_coll_oid) AS (
      SELECT oid FROM pg_catalog.pg_collation
        WHERE collname IN ('nds-x-icu', 'nds-DE-x-icu', 'nds-NL-x-icu', 'mi-x-icu', 'mi-NZ-x-icu')
    )
    DELETE FROM pg_catalog.pg_description
      WHERE objoid IN (SELECT pg_coll_oid FROM descr_delete_oids);
    DELETE FROM pg_catalog.pg_collation
      WHERE collname IN ('nds-x-icu', 'nds-DE-x-icu', 'nds-NL-x-icu');

    -- There are also case changes for some descriptions: (World) becomes (world).
    WITH descr_update_oids(row_number, pg_coll_oid) AS (
      SELECT
        ROW_NUMBER() OVER (ORDER BY oid) AS row_number,
        oid
      FROM pg_catalog.pg_collation
      WHERE collname IN ('ar-001-x-icu', 'en-001-x-icu', 'eo-001-x-icu', 'ia-001-x-icu',
                         'yi-001-x-icu')
    )
    UPDATE pg_catalog.pg_description
    SET
      description = updated_values.description
    FROM (
      VALUES
        (1, 'Arabic (world)'),
        (2, 'English (world)'),
        (3, 'Esperanto (world)'),
        (4, 'Interlingua (world)'),
        (5, 'Yiddish (world)')
    ) AS updated_values (
      row_number, description
    )
    INNER JOIN descr_update_oids ON updated_values.row_number = descr_update_oids.row_number
    WHERE objoid = descr_update_oids.pg_coll_oid;

    -- We cannot delete all the rows in pg_collation and then re-insert them because it
    -- continues allocating new OIDs rather than re-using, resulting in OID bloat.
    -- Instead, we only insert the new collations introduced with the ICU version upgrade
    -- and bulk update the rest of the rows.
    UPDATE pg_catalog.pg_collation
    SET
      collname = updated_values.collname,
      collnamespace = updated_values.collnamespace,
      collowner = updated_values.collowner,
      collprovider = updated_values.collprovider,
      collencoding = updated_values.collencoding,
      collcollate = updated_values.collcollate,
      collctype = updated_values.collctype,
      collversion = updated_values.collversion
    FROM (
      VALUES
        ('und-x-icu', 11, 10, 'i', -1, 'und', 'und', '153.112'),
        ('af-x-icu', 11, 10, 'i', -1, 'af', 'af', '153.112.40'),
        ('af-NA-x-icu', 11, 10, 'i', -1, 'af-NA', 'af-NA', '153.112.40'),
        ('af-ZA-x-icu', 11, 10, 'i', -1, 'af-ZA', 'af-ZA', '153.112.40'),
        ('agq-x-icu', 11, 10, 'i', -1, 'agq', 'agq', '153.112'),
        ('agq-CM-x-icu', 11, 10, 'i', -1, 'agq-CM', 'agq-CM', '153.112'),
        ('ak-x-icu', 11, 10, 'i', -1, 'ak', 'ak', '153.112'),
        ('ak-GH-x-icu', 11, 10, 'i', -1, 'ak-GH', 'ak-GH', '153.112'),
        ('am-x-icu', 11, 10, 'i', -1, 'am', 'am', '153.112.40'),
        ('am-ET-x-icu', 11, 10, 'i', -1, 'am-ET', 'am-ET', '153.112.40'),
        ('ar-x-icu', 11, 10, 'i', -1, 'ar', 'ar', '153.112.40'),
        ('ar-001-x-icu', 11, 10, 'i', -1, 'ar-001', 'ar-001', '153.112.40'),
        ('ar-AE-x-icu', 11, 10, 'i', -1, 'ar-AE', 'ar-AE', '153.112.40'),
        ('ar-BH-x-icu', 11, 10, 'i', -1, 'ar-BH', 'ar-BH', '153.112.40'),
        ('ar-DJ-x-icu', 11, 10, 'i', -1, 'ar-DJ', 'ar-DJ', '153.112.40'),
        ('ar-DZ-x-icu', 11, 10, 'i', -1, 'ar-DZ', 'ar-DZ', '153.112.40'),
        ('ar-EG-x-icu', 11, 10, 'i', -1, 'ar-EG', 'ar-EG', '153.112.40'),
        ('ar-EH-x-icu', 11, 10, 'i', -1, 'ar-EH', 'ar-EH', '153.112.40'),
        ('ar-ER-x-icu', 11, 10, 'i', -1, 'ar-ER', 'ar-ER', '153.112.40'),
        ('ar-IL-x-icu', 11, 10, 'i', -1, 'ar-IL', 'ar-IL', '153.112.40'),
        ('ar-IQ-x-icu', 11, 10, 'i', -1, 'ar-IQ', 'ar-IQ', '153.112.40'),
        ('ar-JO-x-icu', 11, 10, 'i', -1, 'ar-JO', 'ar-JO', '153.112.40'),
        ('ar-KM-x-icu', 11, 10, 'i', -1, 'ar-KM', 'ar-KM', '153.112.40'),
        ('ar-KW-x-icu', 11, 10, 'i', -1, 'ar-KW', 'ar-KW', '153.112.40'),
        ('ar-LB-x-icu', 11, 10, 'i', -1, 'ar-LB', 'ar-LB', '153.112.40'),
        ('ar-LY-x-icu', 11, 10, 'i', -1, 'ar-LY', 'ar-LY', '153.112.40'),
        ('ar-MA-x-icu', 11, 10, 'i', -1, 'ar-MA', 'ar-MA', '153.112.40'),
        ('ar-MR-x-icu', 11, 10, 'i', -1, 'ar-MR', 'ar-MR', '153.112.40'),
        ('ar-OM-x-icu', 11, 10, 'i', -1, 'ar-OM', 'ar-OM', '153.112.40'),
        ('ar-PS-x-icu', 11, 10, 'i', -1, 'ar-PS', 'ar-PS', '153.112.40'),
        ('ar-QA-x-icu', 11, 10, 'i', -1, 'ar-QA', 'ar-QA', '153.112.40'),
        ('ar-SA-x-icu', 11, 10, 'i', -1, 'ar-SA', 'ar-SA', '153.112.40'),
        ('ar-SD-x-icu', 11, 10, 'i', -1, 'ar-SD', 'ar-SD', '153.112.40'),
        ('ar-SO-x-icu', 11, 10, 'i', -1, 'ar-SO', 'ar-SO', '153.112.40'),
        ('ar-SS-x-icu', 11, 10, 'i', -1, 'ar-SS', 'ar-SS', '153.112.40'),
        ('ar-SY-x-icu', 11, 10, 'i', -1, 'ar-SY', 'ar-SY', '153.112.40'),
        ('ar-TD-x-icu', 11, 10, 'i', -1, 'ar-TD', 'ar-TD', '153.112.40'),
        ('ar-TN-x-icu', 11, 10, 'i', -1, 'ar-TN', 'ar-TN', '153.112.40'),
        ('ar-YE-x-icu', 11, 10, 'i', -1, 'ar-YE', 'ar-YE', '153.112.40'),
        ('as-x-icu', 11, 10, 'i', -1, 'as', 'as', '153.112.40'),
        ('as-IN-x-icu', 11, 10, 'i', -1, 'as-IN', 'as-IN', '153.112.40'),
        ('asa-x-icu', 11, 10, 'i', -1, 'asa', 'asa', '153.112'),
        ('asa-TZ-x-icu', 11, 10, 'i', -1, 'asa-TZ', 'asa-TZ', '153.112'),
        ('ast-x-icu', 11, 10, 'i', -1, 'ast', 'ast', '153.112'),
        ('ast-ES-x-icu', 11, 10, 'i', -1, 'ast-ES', 'ast-ES', '153.112'),
        ('az-x-icu', 11, 10, 'i', -1, 'az', 'az', '153.112.40'),
        ('az-Cyrl-x-icu', 11, 10, 'i', -1, 'az-Cyrl', 'az-Cyrl', '153.112.40'),
        ('az-Cyrl-AZ-x-icu', 11, 10, 'i', -1, 'az-Cyrl-AZ', 'az-Cyrl-AZ', '153.112.40'),
        ('az-Latn-x-icu', 11, 10, 'i', -1, 'az-Latn', 'az-Latn', '153.112.40'),
        ('az-Latn-AZ-x-icu', 11, 10, 'i', -1, 'az-Latn-AZ', 'az-Latn-AZ', '153.112.40'),
        ('bas-x-icu', 11, 10, 'i', -1, 'bas', 'bas', '153.112'),
        ('bas-CM-x-icu', 11, 10, 'i', -1, 'bas-CM', 'bas-CM', '153.112'),
        ('be-x-icu', 11, 10, 'i', -1, 'be', 'be', '153.112.40'),
        ('be-BY-x-icu', 11, 10, 'i', -1, 'be-BY', 'be-BY', '153.112.40'),
        ('bem-x-icu', 11, 10, 'i', -1, 'bem', 'bem', '153.112'),
        ('bem-ZM-x-icu', 11, 10, 'i', -1, 'bem-ZM', 'bem-ZM', '153.112'),
        ('bez-x-icu', 11, 10, 'i', -1, 'bez', 'bez', '153.112'),
        ('bez-TZ-x-icu', 11, 10, 'i', -1, 'bez-TZ', 'bez-TZ', '153.112'),
        ('bg-x-icu', 11, 10, 'i', -1, 'bg', 'bg', '153.112.40'),
        ('bg-BG-x-icu', 11, 10, 'i', -1, 'bg-BG', 'bg-BG', '153.112.40'),
        ('bm-x-icu', 11, 10, 'i', -1, 'bm', 'bm', '153.112'),
        ('bm-ML-x-icu', 11, 10, 'i', -1, 'bm-ML', 'bm-ML', '153.112'),
        ('bn-x-icu', 11, 10, 'i', -1, 'bn', 'bn', '153.112.40'),
        ('bn-BD-x-icu', 11, 10, 'i', -1, 'bn-BD', 'bn-BD', '153.112.40'),
        ('bn-IN-x-icu', 11, 10, 'i', -1, 'bn-IN', 'bn-IN', '153.112.40'),
        ('bo-x-icu', 11, 10, 'i', -1, 'bo', 'bo', '153.112.40'),
        ('bo-CN-x-icu', 11, 10, 'i', -1, 'bo-CN', 'bo-CN', '153.112.40'),
        ('bo-IN-x-icu', 11, 10, 'i', -1, 'bo-IN', 'bo-IN', '153.112.40'),
        ('br-x-icu', 11, 10, 'i', -1, 'br', 'br', '153.112.40'),
        ('br-FR-x-icu', 11, 10, 'i', -1, 'br-FR', 'br-FR', '153.112.40'),
        ('brx-x-icu', 11, 10, 'i', -1, 'brx', 'brx', '153.112'),
        ('brx-IN-x-icu', 11, 10, 'i', -1, 'brx-IN', 'brx-IN', '153.112'),
        ('bs-x-icu', 11, 10, 'i', -1, 'bs', 'bs', '153.112.40'),
        ('bs-Cyrl-x-icu', 11, 10, 'i', -1, 'bs-Cyrl', 'bs-Cyrl', '153.112.40'),
        ('bs-Cyrl-BA-x-icu', 11, 10, 'i', -1, 'bs-Cyrl-BA', 'bs-Cyrl-BA', '153.112.40'),
        ('bs-Latn-x-icu', 11, 10, 'i', -1, 'bs-Latn', 'bs-Latn', '153.112.40'),
        ('bs-Latn-BA-x-icu', 11, 10, 'i', -1, 'bs-Latn-BA', 'bs-Latn-BA', '153.112.40'),
        ('ca-x-icu', 11, 10, 'i', -1, 'ca', 'ca', '153.112'),
        ('ca-AD-x-icu', 11, 10, 'i', -1, 'ca-AD', 'ca-AD', '153.112'),
        ('ca-ES-x-icu', 11, 10, 'i', -1, 'ca-ES', 'ca-ES', '153.112'),
        ('ca-FR-x-icu', 11, 10, 'i', -1, 'ca-FR', 'ca-FR', '153.112'),
        ('ca-IT-x-icu', 11, 10, 'i', -1, 'ca-IT', 'ca-IT', '153.112'),
        ('ccp-x-icu', 11, 10, 'i', -1, 'ccp', 'ccp', '153.112'),
        ('ccp-BD-x-icu', 11, 10, 'i', -1, 'ccp-BD', 'ccp-BD', '153.112'),
        ('ccp-IN-x-icu', 11, 10, 'i', -1, 'ccp-IN', 'ccp-IN', '153.112'),
        ('ce-x-icu', 11, 10, 'i', -1, 'ce', 'ce', '153.112'),
        ('ce-RU-x-icu', 11, 10, 'i', -1, 'ce-RU', 'ce-RU', '153.112'),
        ('ceb-x-icu', 11, 10, 'i', -1, 'ceb', 'ceb', '153.112.40'),
        ('ceb-PH-x-icu', 11, 10, 'i', -1, 'ceb-PH', 'ceb-PH', '153.112.40'),
        ('cgg-x-icu', 11, 10, 'i', -1, 'cgg', 'cgg', '153.112'),
        ('cgg-UG-x-icu', 11, 10, 'i', -1, 'cgg-UG', 'cgg-UG', '153.112'),
        ('chr-x-icu', 11, 10, 'i', -1, 'chr', 'chr', '153.112.40'),
        ('chr-US-x-icu', 11, 10, 'i', -1, 'chr-US', 'chr-US', '153.112.40'),
        ('ckb-x-icu', 11, 10, 'i', -1, 'ckb', 'ckb', '153.112'),
        ('ckb-IQ-x-icu', 11, 10, 'i', -1, 'ckb-IQ', 'ckb-IQ', '153.112'),
        ('ckb-IR-x-icu', 11, 10, 'i', -1, 'ckb-IR', 'ckb-IR', '153.112'),
        ('cs-x-icu', 11, 10, 'i', -1, 'cs', 'cs', '153.112.40'),
        ('cs-CZ-x-icu', 11, 10, 'i', -1, 'cs-CZ', 'cs-CZ', '153.112.40'),
        ('cy-x-icu', 11, 10, 'i', -1, 'cy', 'cy', '153.112.40'),
        ('cy-GB-x-icu', 11, 10, 'i', -1, 'cy-GB', 'cy-GB', '153.112.40'),
        ('da-x-icu', 11, 10, 'i', -1, 'da', 'da', '153.112.40'),
        ('da-DK-x-icu', 11, 10, 'i', -1, 'da-DK', 'da-DK', '153.112.40'),
        ('da-GL-x-icu', 11, 10, 'i', -1, 'da-GL', 'da-GL', '153.112.40'),
        ('dav-x-icu', 11, 10, 'i', -1, 'dav', 'dav', '153.112'),
        ('dav-KE-x-icu', 11, 10, 'i', -1, 'dav-KE', 'dav-KE', '153.112'),
        ('de-x-icu', 11, 10, 'i', -1, 'de', 'de', '153.112'),
        ('de-AT-x-icu', 11, 10, 'i', -1, 'de-AT', 'de-AT', '153.112'),
        ('de-BE-x-icu', 11, 10, 'i', -1, 'de-BE', 'de-BE', '153.112'),
        ('de-CH-x-icu', 11, 10, 'i', -1, 'de-CH', 'de-CH', '153.112'),
        ('de-DE-x-icu', 11, 10, 'i', -1, 'de-DE', 'de-DE', '153.112'),
        ('de-IT-x-icu', 11, 10, 'i', -1, 'de-IT', 'de-IT', '153.112'),
        ('de-LI-x-icu', 11, 10, 'i', -1, 'de-LI', 'de-LI', '153.112'),
        ('de-LU-x-icu', 11, 10, 'i', -1, 'de-LU', 'de-LU', '153.112'),
        ('dje-x-icu', 11, 10, 'i', -1, 'dje', 'dje', '153.112'),
        ('dje-NE-x-icu', 11, 10, 'i', -1, 'dje-NE', 'dje-NE', '153.112'),
        ('doi-x-icu', 11, 10, 'i', -1, 'doi', 'doi', '153.112'),
        ('doi-IN-x-icu', 11, 10, 'i', -1, 'doi-IN', 'doi-IN', '153.112'),
        ('dsb-x-icu', 11, 10, 'i', -1, 'dsb', 'dsb', '153.112.40'),
        ('dsb-DE-x-icu', 11, 10, 'i', -1, 'dsb-DE', 'dsb-DE', '153.112.40'),
        ('dua-x-icu', 11, 10, 'i', -1, 'dua', 'dua', '153.112'),
        ('dua-CM-x-icu', 11, 10, 'i', -1, 'dua-CM', 'dua-CM', '153.112'),
        ('dyo-x-icu', 11, 10, 'i', -1, 'dyo', 'dyo', '153.112'),
        ('dyo-SN-x-icu', 11, 10, 'i', -1, 'dyo-SN', 'dyo-SN', '153.112'),
        ('dz-x-icu', 11, 10, 'i', -1, 'dz', 'dz', '153.112'),
        ('dz-BT-x-icu', 11, 10, 'i', -1, 'dz-BT', 'dz-BT', '153.112'),
        ('ebu-x-icu', 11, 10, 'i', -1, 'ebu', 'ebu', '153.112'),
        ('ebu-KE-x-icu', 11, 10, 'i', -1, 'ebu-KE', 'ebu-KE', '153.112'),
        ('ee-x-icu', 11, 10, 'i', -1, 'ee', 'ee', '153.112.40'),
        ('ee-GH-x-icu', 11, 10, 'i', -1, 'ee-GH', 'ee-GH', '153.112.40'),
        ('ee-TG-x-icu', 11, 10, 'i', -1, 'ee-TG', 'ee-TG', '153.112.40'),
        ('el-x-icu', 11, 10, 'i', -1, 'el', 'el', '153.112.40'),
        ('el-CY-x-icu', 11, 10, 'i', -1, 'el-CY', 'el-CY', '153.112.40'),
        ('el-GR-x-icu', 11, 10, 'i', -1, 'el-GR', 'el-GR', '153.112.40'),
        ('en-x-icu', 11, 10, 'i', -1, 'en', 'en', '153.112'),
        ('en-001-x-icu', 11, 10, 'i', -1, 'en-001', 'en-001', '153.112'),
        ('en-150-x-icu', 11, 10, 'i', -1, 'en-150', 'en-150', '153.112'),
        ('en-AE-x-icu', 11, 10, 'i', -1, 'en-AE', 'en-AE', '153.112'),
        ('en-AG-x-icu', 11, 10, 'i', -1, 'en-AG', 'en-AG', '153.112'),
        ('en-AI-x-icu', 11, 10, 'i', -1, 'en-AI', 'en-AI', '153.112'),
        ('en-AS-x-icu', 11, 10, 'i', -1, 'en-AS', 'en-AS', '153.112'),
        ('en-AT-x-icu', 11, 10, 'i', -1, 'en-AT', 'en-AT', '153.112'),
        ('en-AU-x-icu', 11, 10, 'i', -1, 'en-AU', 'en-AU', '153.112'),
        ('en-BB-x-icu', 11, 10, 'i', -1, 'en-BB', 'en-BB', '153.112'),
        ('en-BE-x-icu', 11, 10, 'i', -1, 'en-BE', 'en-BE', '153.112'),
        ('en-BI-x-icu', 11, 10, 'i', -1, 'en-BI', 'en-BI', '153.112'),
        ('en-BM-x-icu', 11, 10, 'i', -1, 'en-BM', 'en-BM', '153.112'),
        ('en-BS-x-icu', 11, 10, 'i', -1, 'en-BS', 'en-BS', '153.112'),
        ('en-BW-x-icu', 11, 10, 'i', -1, 'en-BW', 'en-BW', '153.112'),
        ('en-BZ-x-icu', 11, 10, 'i', -1, 'en-BZ', 'en-BZ', '153.112'),
        ('en-CA-x-icu', 11, 10, 'i', -1, 'en-CA', 'en-CA', '153.112'),
        ('en-CC-x-icu', 11, 10, 'i', -1, 'en-CC', 'en-CC', '153.112'),
        ('en-CH-x-icu', 11, 10, 'i', -1, 'en-CH', 'en-CH', '153.112'),
        ('en-CK-x-icu', 11, 10, 'i', -1, 'en-CK', 'en-CK', '153.112'),
        ('en-CM-x-icu', 11, 10, 'i', -1, 'en-CM', 'en-CM', '153.112'),
        ('en-CX-x-icu', 11, 10, 'i', -1, 'en-CX', 'en-CX', '153.112'),
        ('en-CY-x-icu', 11, 10, 'i', -1, 'en-CY', 'en-CY', '153.112'),
        ('en-DE-x-icu', 11, 10, 'i', -1, 'en-DE', 'en-DE', '153.112'),
        ('en-DG-x-icu', 11, 10, 'i', -1, 'en-DG', 'en-DG', '153.112'),
        ('en-DK-x-icu', 11, 10, 'i', -1, 'en-DK', 'en-DK', '153.112'),
        ('en-DM-x-icu', 11, 10, 'i', -1, 'en-DM', 'en-DM', '153.112'),
        ('en-ER-x-icu', 11, 10, 'i', -1, 'en-ER', 'en-ER', '153.112'),
        ('en-FI-x-icu', 11, 10, 'i', -1, 'en-FI', 'en-FI', '153.112'),
        ('en-FJ-x-icu', 11, 10, 'i', -1, 'en-FJ', 'en-FJ', '153.112'),
        ('en-FK-x-icu', 11, 10, 'i', -1, 'en-FK', 'en-FK', '153.112'),
        ('en-FM-x-icu', 11, 10, 'i', -1, 'en-FM', 'en-FM', '153.112'),
        ('en-GB-x-icu', 11, 10, 'i', -1, 'en-GB', 'en-GB', '153.112'),
        ('en-GD-x-icu', 11, 10, 'i', -1, 'en-GD', 'en-GD', '153.112'),
        ('en-GG-x-icu', 11, 10, 'i', -1, 'en-GG', 'en-GG', '153.112'),
        ('en-GH-x-icu', 11, 10, 'i', -1, 'en-GH', 'en-GH', '153.112'),
        ('en-GI-x-icu', 11, 10, 'i', -1, 'en-GI', 'en-GI', '153.112'),
        ('en-GM-x-icu', 11, 10, 'i', -1, 'en-GM', 'en-GM', '153.112'),
        ('en-GU-x-icu', 11, 10, 'i', -1, 'en-GU', 'en-GU', '153.112'),
        ('en-GY-x-icu', 11, 10, 'i', -1, 'en-GY', 'en-GY', '153.112'),
        ('en-HK-x-icu', 11, 10, 'i', -1, 'en-HK', 'en-HK', '153.112'),
        ('en-IE-x-icu', 11, 10, 'i', -1, 'en-IE', 'en-IE', '153.112'),
        ('en-IL-x-icu', 11, 10, 'i', -1, 'en-IL', 'en-IL', '153.112'),
        ('en-IM-x-icu', 11, 10, 'i', -1, 'en-IM', 'en-IM', '153.112'),
        ('en-IN-x-icu', 11, 10, 'i', -1, 'en-IN', 'en-IN', '153.112'),
        ('en-IO-x-icu', 11, 10, 'i', -1, 'en-IO', 'en-IO', '153.112'),
        ('en-JE-x-icu', 11, 10, 'i', -1, 'en-JE', 'en-JE', '153.112'),
        ('en-JM-x-icu', 11, 10, 'i', -1, 'en-JM', 'en-JM', '153.112'),
        ('en-KE-x-icu', 11, 10, 'i', -1, 'en-KE', 'en-KE', '153.112'),
        ('en-KI-x-icu', 11, 10, 'i', -1, 'en-KI', 'en-KI', '153.112'),
        ('en-KN-x-icu', 11, 10, 'i', -1, 'en-KN', 'en-KN', '153.112'),
        ('en-KY-x-icu', 11, 10, 'i', -1, 'en-KY', 'en-KY', '153.112'),
        ('en-LC-x-icu', 11, 10, 'i', -1, 'en-LC', 'en-LC', '153.112'),
        ('en-LR-x-icu', 11, 10, 'i', -1, 'en-LR', 'en-LR', '153.112'),
        ('en-LS-x-icu', 11, 10, 'i', -1, 'en-LS', 'en-LS', '153.112'),
        ('en-MG-x-icu', 11, 10, 'i', -1, 'en-MG', 'en-MG', '153.112'),
        ('en-MH-x-icu', 11, 10, 'i', -1, 'en-MH', 'en-MH', '153.112'),
        ('en-MO-x-icu', 11, 10, 'i', -1, 'en-MO', 'en-MO', '153.112'),
        ('en-MP-x-icu', 11, 10, 'i', -1, 'en-MP', 'en-MP', '153.112'),
        ('en-MS-x-icu', 11, 10, 'i', -1, 'en-MS', 'en-MS', '153.112'),
        ('en-MT-x-icu', 11, 10, 'i', -1, 'en-MT', 'en-MT', '153.112'),
        ('en-MU-x-icu', 11, 10, 'i', -1, 'en-MU', 'en-MU', '153.112'),
        ('en-MW-x-icu', 11, 10, 'i', -1, 'en-MW', 'en-MW', '153.112'),
        ('en-MY-x-icu', 11, 10, 'i', -1, 'en-MY', 'en-MY', '153.112'),
        ('en-NA-x-icu', 11, 10, 'i', -1, 'en-NA', 'en-NA', '153.112'),
        ('en-NF-x-icu', 11, 10, 'i', -1, 'en-NF', 'en-NF', '153.112'),
        ('en-NG-x-icu', 11, 10, 'i', -1, 'en-NG', 'en-NG', '153.112'),
        ('en-NL-x-icu', 11, 10, 'i', -1, 'en-NL', 'en-NL', '153.112'),
        ('en-NR-x-icu', 11, 10, 'i', -1, 'en-NR', 'en-NR', '153.112'),
        ('en-NU-x-icu', 11, 10, 'i', -1, 'en-NU', 'en-NU', '153.112'),
        ('en-NZ-x-icu', 11, 10, 'i', -1, 'en-NZ', 'en-NZ', '153.112'),
        ('en-PG-x-icu', 11, 10, 'i', -1, 'en-PG', 'en-PG', '153.112'),
        ('en-PH-x-icu', 11, 10, 'i', -1, 'en-PH', 'en-PH', '153.112'),
        ('en-PK-x-icu', 11, 10, 'i', -1, 'en-PK', 'en-PK', '153.112'),
        ('en-PN-x-icu', 11, 10, 'i', -1, 'en-PN', 'en-PN', '153.112'),
        ('en-PR-x-icu', 11, 10, 'i', -1, 'en-PR', 'en-PR', '153.112'),
        ('en-PW-x-icu', 11, 10, 'i', -1, 'en-PW', 'en-PW', '153.112'),
        ('en-RW-x-icu', 11, 10, 'i', -1, 'en-RW', 'en-RW', '153.112'),
        ('en-SB-x-icu', 11, 10, 'i', -1, 'en-SB', 'en-SB', '153.112'),
        ('en-SC-x-icu', 11, 10, 'i', -1, 'en-SC', 'en-SC', '153.112'),
        ('en-SD-x-icu', 11, 10, 'i', -1, 'en-SD', 'en-SD', '153.112'),
        ('en-SE-x-icu', 11, 10, 'i', -1, 'en-SE', 'en-SE', '153.112'),
        ('en-SG-x-icu', 11, 10, 'i', -1, 'en-SG', 'en-SG', '153.112'),
        ('en-SH-x-icu', 11, 10, 'i', -1, 'en-SH', 'en-SH', '153.112'),
        ('en-SI-x-icu', 11, 10, 'i', -1, 'en-SI', 'en-SI', '153.112'),
        ('en-SL-x-icu', 11, 10, 'i', -1, 'en-SL', 'en-SL', '153.112'),
        ('en-SS-x-icu', 11, 10, 'i', -1, 'en-SS', 'en-SS', '153.112'),
        ('en-SX-x-icu', 11, 10, 'i', -1, 'en-SX', 'en-SX', '153.112'),
        ('en-SZ-x-icu', 11, 10, 'i', -1, 'en-SZ', 'en-SZ', '153.112'),
        ('en-TC-x-icu', 11, 10, 'i', -1, 'en-TC', 'en-TC', '153.112'),
        ('en-TK-x-icu', 11, 10, 'i', -1, 'en-TK', 'en-TK', '153.112'),
        ('en-TO-x-icu', 11, 10, 'i', -1, 'en-TO', 'en-TO', '153.112'),
        ('en-TT-x-icu', 11, 10, 'i', -1, 'en-TT', 'en-TT', '153.112'),
        ('en-TV-x-icu', 11, 10, 'i', -1, 'en-TV', 'en-TV', '153.112'),
        ('en-TZ-x-icu', 11, 10, 'i', -1, 'en-TZ', 'en-TZ', '153.112'),
        ('en-UG-x-icu', 11, 10, 'i', -1, 'en-UG', 'en-UG', '153.112'),
        ('en-UM-x-icu', 11, 10, 'i', -1, 'en-UM', 'en-UM', '153.112'),
        ('en-US-x-icu', 11, 10, 'i', -1, 'en-US', 'en-US', '153.112'),
        ('en-US-u-va-posix-x-icu', 11, 10, 'i', -1, 'en-US-u-va-posix', 'en-US-u-va-posix', '153.112.40'),
        ('en-VC-x-icu', 11, 10, 'i', -1, 'en-VC', 'en-VC', '153.112'),
        ('en-VG-x-icu', 11, 10, 'i', -1, 'en-VG', 'en-VG', '153.112'),
        ('en-VI-x-icu', 11, 10, 'i', -1, 'en-VI', 'en-VI', '153.112'),
        ('en-VU-x-icu', 11, 10, 'i', -1, 'en-VU', 'en-VU', '153.112'),
        ('en-WS-x-icu', 11, 10, 'i', -1, 'en-WS', 'en-WS', '153.112'),
        ('en-ZA-x-icu', 11, 10, 'i', -1, 'en-ZA', 'en-ZA', '153.112'),
        ('en-ZM-x-icu', 11, 10, 'i', -1, 'en-ZM', 'en-ZM', '153.112'),
        ('en-ZW-x-icu', 11, 10, 'i', -1, 'en-ZW', 'en-ZW', '153.112'),
        ('eo-x-icu', 11, 10, 'i', -1, 'eo', 'eo', '153.112.40'),
        ('eo-001-x-icu', 11, 10, 'i', -1, 'eo-001', 'eo-001', '153.112.40'),
        ('es-x-icu', 11, 10, 'i', -1, 'es', 'es', '153.112.40'),
        ('es-419-x-icu', 11, 10, 'i', -1, 'es-419', 'es-419', '153.112.40'),
        ('es-AR-x-icu', 11, 10, 'i', -1, 'es-AR', 'es-AR', '153.112.40'),
        ('es-BO-x-icu', 11, 10, 'i', -1, 'es-BO', 'es-BO', '153.112.40'),
        ('es-BR-x-icu', 11, 10, 'i', -1, 'es-BR', 'es-BR', '153.112.40'),
        ('es-BZ-x-icu', 11, 10, 'i', -1, 'es-BZ', 'es-BZ', '153.112.40'),
        ('es-CL-x-icu', 11, 10, 'i', -1, 'es-CL', 'es-CL', '153.112.40'),
        ('es-CO-x-icu', 11, 10, 'i', -1, 'es-CO', 'es-CO', '153.112.40'),
        ('es-CR-x-icu', 11, 10, 'i', -1, 'es-CR', 'es-CR', '153.112.40'),
        ('es-CU-x-icu', 11, 10, 'i', -1, 'es-CU', 'es-CU', '153.112.40'),
        ('es-DO-x-icu', 11, 10, 'i', -1, 'es-DO', 'es-DO', '153.112.40'),
        ('es-EA-x-icu', 11, 10, 'i', -1, 'es-EA', 'es-EA', '153.112.40'),
        ('es-EC-x-icu', 11, 10, 'i', -1, 'es-EC', 'es-EC', '153.112.40'),
        ('es-ES-x-icu', 11, 10, 'i', -1, 'es-ES', 'es-ES', '153.112.40'),
        ('es-GQ-x-icu', 11, 10, 'i', -1, 'es-GQ', 'es-GQ', '153.112.40'),
        ('es-GT-x-icu', 11, 10, 'i', -1, 'es-GT', 'es-GT', '153.112.40'),
        ('es-HN-x-icu', 11, 10, 'i', -1, 'es-HN', 'es-HN', '153.112.40'),
        ('es-IC-x-icu', 11, 10, 'i', -1, 'es-IC', 'es-IC', '153.112.40'),
        ('es-MX-x-icu', 11, 10, 'i', -1, 'es-MX', 'es-MX', '153.112.40'),
        ('es-NI-x-icu', 11, 10, 'i', -1, 'es-NI', 'es-NI', '153.112.40'),
        ('es-PA-x-icu', 11, 10, 'i', -1, 'es-PA', 'es-PA', '153.112.40'),
        ('es-PE-x-icu', 11, 10, 'i', -1, 'es-PE', 'es-PE', '153.112.40'),
        ('es-PH-x-icu', 11, 10, 'i', -1, 'es-PH', 'es-PH', '153.112.40'),
        ('es-PR-x-icu', 11, 10, 'i', -1, 'es-PR', 'es-PR', '153.112.40'),
        ('es-PY-x-icu', 11, 10, 'i', -1, 'es-PY', 'es-PY', '153.112.40'),
        ('es-SV-x-icu', 11, 10, 'i', -1, 'es-SV', 'es-SV', '153.112.40'),
        ('es-US-x-icu', 11, 10, 'i', -1, 'es-US', 'es-US', '153.112.40'),
        ('es-UY-x-icu', 11, 10, 'i', -1, 'es-UY', 'es-UY', '153.112.40'),
        ('es-VE-x-icu', 11, 10, 'i', -1, 'es-VE', 'es-VE', '153.112.40'),
        ('et-x-icu', 11, 10, 'i', -1, 'et', 'et', '153.112.40'),
        ('et-EE-x-icu', 11, 10, 'i', -1, 'et-EE', 'et-EE', '153.112.40'),
        ('eu-x-icu', 11, 10, 'i', -1, 'eu', 'eu', '153.112'),
        ('eu-ES-x-icu', 11, 10, 'i', -1, 'eu-ES', 'eu-ES', '153.112'),
        ('ewo-x-icu', 11, 10, 'i', -1, 'ewo', 'ewo', '153.112'),
        ('ewo-CM-x-icu', 11, 10, 'i', -1, 'ewo-CM', 'ewo-CM', '153.112'),
        ('fa-x-icu', 11, 10, 'i', -1, 'fa', 'fa', '153.112.40'),
        ('fa-AF-x-icu', 11, 10, 'i', -1, 'fa-AF', 'fa-AF', '153.112.40'),
        ('fa-IR-x-icu', 11, 10, 'i', -1, 'fa-IR', 'fa-IR', '153.112.40'),
        ('ff-x-icu', 11, 10, 'i', -1, 'ff', 'ff', '153.112'),
        ('ff-Adlm-x-icu', 11, 10, 'i', -1, 'ff-Adlm', 'ff-Adlm', '153.112.40'),
        ('ff-Adlm-BF-x-icu', 11, 10, 'i', -1, 'ff-Adlm-BF', 'ff-Adlm-BF', '153.112.40'),
        ('ff-Adlm-CM-x-icu', 11, 10, 'i', -1, 'ff-Adlm-CM', 'ff-Adlm-CM', '153.112.40'),
        ('ff-Adlm-GH-x-icu', 11, 10, 'i', -1, 'ff-Adlm-GH', 'ff-Adlm-GH', '153.112.40'),
        ('ff-Adlm-GM-x-icu', 11, 10, 'i', -1, 'ff-Adlm-GM', 'ff-Adlm-GM', '153.112.40'),
        ('ff-Adlm-GN-x-icu', 11, 10, 'i', -1, 'ff-Adlm-GN', 'ff-Adlm-GN', '153.112.40'),
        ('ff-Adlm-GW-x-icu', 11, 10, 'i', -1, 'ff-Adlm-GW', 'ff-Adlm-GW', '153.112.40'),
        ('ff-Adlm-LR-x-icu', 11, 10, 'i', -1, 'ff-Adlm-LR', 'ff-Adlm-LR', '153.112.40'),
        ('ff-Adlm-MR-x-icu', 11, 10, 'i', -1, 'ff-Adlm-MR', 'ff-Adlm-MR', '153.112.40'),
        ('ff-Adlm-NE-x-icu', 11, 10, 'i', -1, 'ff-Adlm-NE', 'ff-Adlm-NE', '153.112.40'),
        ('ff-Adlm-NG-x-icu', 11, 10, 'i', -1, 'ff-Adlm-NG', 'ff-Adlm-NG', '153.112.40'),
        ('ff-Adlm-SL-x-icu', 11, 10, 'i', -1, 'ff-Adlm-SL', 'ff-Adlm-SL', '153.112.40'),
        ('ff-Adlm-SN-x-icu', 11, 10, 'i', -1, 'ff-Adlm-SN', 'ff-Adlm-SN', '153.112.40'),
        ('ff-Latn-x-icu', 11, 10, 'i', -1, 'ff-Latn', 'ff-Latn', '153.112'),
        ('ff-Latn-BF-x-icu', 11, 10, 'i', -1, 'ff-Latn-BF', 'ff-Latn-BF', '153.112'),
        ('ff-Latn-CM-x-icu', 11, 10, 'i', -1, 'ff-Latn-CM', 'ff-Latn-CM', '153.112'),
        ('ff-Latn-GH-x-icu', 11, 10, 'i', -1, 'ff-Latn-GH', 'ff-Latn-GH', '153.112'),
        ('ff-Latn-GM-x-icu', 11, 10, 'i', -1, 'ff-Latn-GM', 'ff-Latn-GM', '153.112'),
        ('ff-Latn-GN-x-icu', 11, 10, 'i', -1, 'ff-Latn-GN', 'ff-Latn-GN', '153.112'),
        ('ff-Latn-GW-x-icu', 11, 10, 'i', -1, 'ff-Latn-GW', 'ff-Latn-GW', '153.112'),
        ('ff-Latn-LR-x-icu', 11, 10, 'i', -1, 'ff-Latn-LR', 'ff-Latn-LR', '153.112'),
        ('ff-Latn-MR-x-icu', 11, 10, 'i', -1, 'ff-Latn-MR', 'ff-Latn-MR', '153.112'),
        ('ff-Latn-NE-x-icu', 11, 10, 'i', -1, 'ff-Latn-NE', 'ff-Latn-NE', '153.112'),
        ('ff-Latn-NG-x-icu', 11, 10, 'i', -1, 'ff-Latn-NG', 'ff-Latn-NG', '153.112'),
        ('ff-Latn-SL-x-icu', 11, 10, 'i', -1, 'ff-Latn-SL', 'ff-Latn-SL', '153.112'),
        ('ff-Latn-SN-x-icu', 11, 10, 'i', -1, 'ff-Latn-SN', 'ff-Latn-SN', '153.112'),
        ('fi-x-icu', 11, 10, 'i', -1, 'fi', 'fi', '153.112.40'),
        ('fi-FI-x-icu', 11, 10, 'i', -1, 'fi-FI', 'fi-FI', '153.112.40'),
        ('fil-x-icu', 11, 10, 'i', -1, 'fil', 'fil', '153.112.40'),
        ('fil-PH-x-icu', 11, 10, 'i', -1, 'fil-PH', 'fil-PH', '153.112.40'),
        ('fo-x-icu', 11, 10, 'i', -1, 'fo', 'fo', '153.112.40'),
        ('fo-DK-x-icu', 11, 10, 'i', -1, 'fo-DK', 'fo-DK', '153.112.40'),
        ('fo-FO-x-icu', 11, 10, 'i', -1, 'fo-FO', 'fo-FO', '153.112.40'),
        ('fr-x-icu', 11, 10, 'i', -1, 'fr', 'fr', '153.112'),
        ('fr-BE-x-icu', 11, 10, 'i', -1, 'fr-BE', 'fr-BE', '153.112'),
        ('fr-BF-x-icu', 11, 10, 'i', -1, 'fr-BF', 'fr-BF', '153.112'),
        ('fr-BI-x-icu', 11, 10, 'i', -1, 'fr-BI', 'fr-BI', '153.112'),
        ('fr-BJ-x-icu', 11, 10, 'i', -1, 'fr-BJ', 'fr-BJ', '153.112'),
        ('fr-BL-x-icu', 11, 10, 'i', -1, 'fr-BL', 'fr-BL', '153.112'),
        ('fr-CA-x-icu', 11, 10, 'i', -1, 'fr-CA', 'fr-CA', '153.112.40'),
        ('fr-CD-x-icu', 11, 10, 'i', -1, 'fr-CD', 'fr-CD', '153.112'),
        ('fr-CF-x-icu', 11, 10, 'i', -1, 'fr-CF', 'fr-CF', '153.112'),
        ('fr-CG-x-icu', 11, 10, 'i', -1, 'fr-CG', 'fr-CG', '153.112'),
        ('fr-CH-x-icu', 11, 10, 'i', -1, 'fr-CH', 'fr-CH', '153.112'),
        ('fr-CI-x-icu', 11, 10, 'i', -1, 'fr-CI', 'fr-CI', '153.112'),
        ('fr-CM-x-icu', 11, 10, 'i', -1, 'fr-CM', 'fr-CM', '153.112'),
        ('fr-DJ-x-icu', 11, 10, 'i', -1, 'fr-DJ', 'fr-DJ', '153.112'),
        ('fr-DZ-x-icu', 11, 10, 'i', -1, 'fr-DZ', 'fr-DZ', '153.112'),
        ('fr-FR-x-icu', 11, 10, 'i', -1, 'fr-FR', 'fr-FR', '153.112'),
        ('fr-GA-x-icu', 11, 10, 'i', -1, 'fr-GA', 'fr-GA', '153.112'),
        ('fr-GF-x-icu', 11, 10, 'i', -1, 'fr-GF', 'fr-GF', '153.112'),
        ('fr-GN-x-icu', 11, 10, 'i', -1, 'fr-GN', 'fr-GN', '153.112'),
        ('fr-GP-x-icu', 11, 10, 'i', -1, 'fr-GP', 'fr-GP', '153.112'),
        ('fr-GQ-x-icu', 11, 10, 'i', -1, 'fr-GQ', 'fr-GQ', '153.112'),
        ('fr-HT-x-icu', 11, 10, 'i', -1, 'fr-HT', 'fr-HT', '153.112'),
        ('fr-KM-x-icu', 11, 10, 'i', -1, 'fr-KM', 'fr-KM', '153.112'),
        ('fr-LU-x-icu', 11, 10, 'i', -1, 'fr-LU', 'fr-LU', '153.112'),
        ('fr-MA-x-icu', 11, 10, 'i', -1, 'fr-MA', 'fr-MA', '153.112'),
        ('fr-MC-x-icu', 11, 10, 'i', -1, 'fr-MC', 'fr-MC', '153.112'),
        ('fr-MF-x-icu', 11, 10, 'i', -1, 'fr-MF', 'fr-MF', '153.112'),
        ('fr-MG-x-icu', 11, 10, 'i', -1, 'fr-MG', 'fr-MG', '153.112'),
        ('fr-ML-x-icu', 11, 10, 'i', -1, 'fr-ML', 'fr-ML', '153.112'),
        ('fr-MQ-x-icu', 11, 10, 'i', -1, 'fr-MQ', 'fr-MQ', '153.112'),
        ('fr-MR-x-icu', 11, 10, 'i', -1, 'fr-MR', 'fr-MR', '153.112'),
        ('fr-MU-x-icu', 11, 10, 'i', -1, 'fr-MU', 'fr-MU', '153.112'),
        ('fr-NC-x-icu', 11, 10, 'i', -1, 'fr-NC', 'fr-NC', '153.112'),
        ('fr-NE-x-icu', 11, 10, 'i', -1, 'fr-NE', 'fr-NE', '153.112'),
        ('fr-PF-x-icu', 11, 10, 'i', -1, 'fr-PF', 'fr-PF', '153.112'),
        ('fr-PM-x-icu', 11, 10, 'i', -1, 'fr-PM', 'fr-PM', '153.112'),
        ('fr-RE-x-icu', 11, 10, 'i', -1, 'fr-RE', 'fr-RE', '153.112'),
        ('fr-RW-x-icu', 11, 10, 'i', -1, 'fr-RW', 'fr-RW', '153.112'),
        ('fr-SC-x-icu', 11, 10, 'i', -1, 'fr-SC', 'fr-SC', '153.112'),
        ('fr-SN-x-icu', 11, 10, 'i', -1, 'fr-SN', 'fr-SN', '153.112'),
        ('fr-SY-x-icu', 11, 10, 'i', -1, 'fr-SY', 'fr-SY', '153.112'),
        ('fr-TD-x-icu', 11, 10, 'i', -1, 'fr-TD', 'fr-TD', '153.112'),
        ('fr-TG-x-icu', 11, 10, 'i', -1, 'fr-TG', 'fr-TG', '153.112'),
        ('fr-TN-x-icu', 11, 10, 'i', -1, 'fr-TN', 'fr-TN', '153.112'),
        ('fr-VU-x-icu', 11, 10, 'i', -1, 'fr-VU', 'fr-VU', '153.112'),
        ('fr-WF-x-icu', 11, 10, 'i', -1, 'fr-WF', 'fr-WF', '153.112'),
        ('fr-YT-x-icu', 11, 10, 'i', -1, 'fr-YT', 'fr-YT', '153.112'),
        ('fur-x-icu', 11, 10, 'i', -1, 'fur', 'fur', '153.112'),
        ('fur-IT-x-icu', 11, 10, 'i', -1, 'fur-IT', 'fur-IT', '153.112'),
        ('fy-x-icu', 11, 10, 'i', -1, 'fy', 'fy', '153.112'),
        ('fy-NL-x-icu', 11, 10, 'i', -1, 'fy-NL', 'fy-NL', '153.112'),
        ('ga-x-icu', 11, 10, 'i', -1, 'ga', 'ga', '153.112'),
        ('ga-GB-x-icu', 11, 10, 'i', -1, 'ga-GB', 'ga-GB', '153.112'),
        ('ga-IE-x-icu', 11, 10, 'i', -1, 'ga-IE', 'ga-IE', '153.112'),
        ('gd-x-icu', 11, 10, 'i', -1, 'gd', 'gd', '153.112'),
        ('gd-GB-x-icu', 11, 10, 'i', -1, 'gd-GB', 'gd-GB', '153.112'),
        ('gl-x-icu', 11, 10, 'i', -1, 'gl', 'gl', '153.112.40'),
        ('gl-ES-x-icu', 11, 10, 'i', -1, 'gl-ES', 'gl-ES', '153.112.40'),
        ('gsw-x-icu', 11, 10, 'i', -1, 'gsw', 'gsw', '153.112'),
        ('gsw-CH-x-icu', 11, 10, 'i', -1, 'gsw-CH', 'gsw-CH', '153.112'),
        ('gsw-FR-x-icu', 11, 10, 'i', -1, 'gsw-FR', 'gsw-FR', '153.112'),
        ('gsw-LI-x-icu', 11, 10, 'i', -1, 'gsw-LI', 'gsw-LI', '153.112'),
        ('gu-x-icu', 11, 10, 'i', -1, 'gu', 'gu', '153.112.40'),
        ('gu-IN-x-icu', 11, 10, 'i', -1, 'gu-IN', 'gu-IN', '153.112.40'),
        ('guz-x-icu', 11, 10, 'i', -1, 'guz', 'guz', '153.112'),
        ('guz-KE-x-icu', 11, 10, 'i', -1, 'guz-KE', 'guz-KE', '153.112'),
        ('gv-x-icu', 11, 10, 'i', -1, 'gv', 'gv', '153.112'),
        ('gv-IM-x-icu', 11, 10, 'i', -1, 'gv-IM', 'gv-IM', '153.112'),
        ('ha-x-icu', 11, 10, 'i', -1, 'ha', 'ha', '153.112.40'),
        ('ha-GH-x-icu', 11, 10, 'i', -1, 'ha-GH', 'ha-GH', '153.112.40'),
        ('ha-NE-x-icu', 11, 10, 'i', -1, 'ha-NE', 'ha-NE', '153.112.40'),
        ('ha-NG-x-icu', 11, 10, 'i', -1, 'ha-NG', 'ha-NG', '153.112.40'),
        ('haw-x-icu', 11, 10, 'i', -1, 'haw', 'haw', '153.112.40'),
        ('haw-US-x-icu', 11, 10, 'i', -1, 'haw-US', 'haw-US', '153.112.40'),
        ('he-x-icu', 11, 10, 'i', -1, 'he', 'he', '153.112.40'),
        ('he-IL-x-icu', 11, 10, 'i', -1, 'he-IL', 'he-IL', '153.112.40'),
        ('hi-x-icu', 11, 10, 'i', -1, 'hi', 'hi', '153.112.40'),
        ('hi-IN-x-icu', 11, 10, 'i', -1, 'hi-IN', 'hi-IN', '153.112.40'),
        ('hr-x-icu', 11, 10, 'i', -1, 'hr', 'hr', '153.112.40'),
        ('hr-BA-x-icu', 11, 10, 'i', -1, 'hr-BA', 'hr-BA', '153.112.40'),
        ('hr-HR-x-icu', 11, 10, 'i', -1, 'hr-HR', 'hr-HR', '153.112.40'),
        ('hsb-x-icu', 11, 10, 'i', -1, 'hsb', 'hsb', '153.112.40'),
        ('hsb-DE-x-icu', 11, 10, 'i', -1, 'hsb-DE', 'hsb-DE', '153.112.40'),
        ('hu-x-icu', 11, 10, 'i', -1, 'hu', 'hu', '153.112.40'),
        ('hu-HU-x-icu', 11, 10, 'i', -1, 'hu-HU', 'hu-HU', '153.112.40'),
        ('hy-x-icu', 11, 10, 'i', -1, 'hy', 'hy', '153.112.40'),
        ('hy-AM-x-icu', 11, 10, 'i', -1, 'hy-AM', 'hy-AM', '153.112.40'),
        ('ia-x-icu', 11, 10, 'i', -1, 'ia', 'ia', '153.112'),
        ('ia-001-x-icu', 11, 10, 'i', -1, 'ia-001', 'ia-001', '153.112'),
        ('id-x-icu', 11, 10, 'i', -1, 'id', 'id', '153.112'),
        ('id-ID-x-icu', 11, 10, 'i', -1, 'id-ID', 'id-ID', '153.112'),
        ('ig-x-icu', 11, 10, 'i', -1, 'ig', 'ig', '153.112.40'),
        ('ig-NG-x-icu', 11, 10, 'i', -1, 'ig-NG', 'ig-NG', '153.112.40'),
        ('ii-x-icu', 11, 10, 'i', -1, 'ii', 'ii', '153.112'),
        ('ii-CN-x-icu', 11, 10, 'i', -1, 'ii-CN', 'ii-CN', '153.112'),
        ('is-x-icu', 11, 10, 'i', -1, 'is', 'is', '153.112.40'),
        ('is-IS-x-icu', 11, 10, 'i', -1, 'is-IS', 'is-IS', '153.112.40'),
        ('it-x-icu', 11, 10, 'i', -1, 'it', 'it', '153.112'),
        ('it-CH-x-icu', 11, 10, 'i', -1, 'it-CH', 'it-CH', '153.112'),
        ('it-IT-x-icu', 11, 10, 'i', -1, 'it-IT', 'it-IT', '153.112'),
        ('it-SM-x-icu', 11, 10, 'i', -1, 'it-SM', 'it-SM', '153.112'),
        ('it-VA-x-icu', 11, 10, 'i', -1, 'it-VA', 'it-VA', '153.112'),
        ('ja-x-icu', 11, 10, 'i', -1, 'ja', 'ja', '153.112.40'),
        ('ja-JP-x-icu', 11, 10, 'i', -1, 'ja-JP', 'ja-JP', '153.112.40'),
        ('jgo-x-icu', 11, 10, 'i', -1, 'jgo', 'jgo', '153.112'),
        ('jgo-CM-x-icu', 11, 10, 'i', -1, 'jgo-CM', 'jgo-CM', '153.112'),
        ('jmc-x-icu', 11, 10, 'i', -1, 'jmc', 'jmc', '153.112'),
        ('jmc-TZ-x-icu', 11, 10, 'i', -1, 'jmc-TZ', 'jmc-TZ', '153.112'),
        ('jv-x-icu', 11, 10, 'i', -1, 'jv', 'jv', '153.112'),
        ('jv-ID-x-icu', 11, 10, 'i', -1, 'jv-ID', 'jv-ID', '153.112'),
        ('ka-x-icu', 11, 10, 'i', -1, 'ka', 'ka', '153.112.40'),
        ('ka-GE-x-icu', 11, 10, 'i', -1, 'ka-GE', 'ka-GE', '153.112.40'),
        ('kab-x-icu', 11, 10, 'i', -1, 'kab', 'kab', '153.112'),
        ('kab-DZ-x-icu', 11, 10, 'i', -1, 'kab-DZ', 'kab-DZ', '153.112'),
        ('kam-x-icu', 11, 10, 'i', -1, 'kam', 'kam', '153.112'),
        ('kam-KE-x-icu', 11, 10, 'i', -1, 'kam-KE', 'kam-KE', '153.112'),
        ('kde-x-icu', 11, 10, 'i', -1, 'kde', 'kde', '153.112'),
        ('kde-TZ-x-icu', 11, 10, 'i', -1, 'kde-TZ', 'kde-TZ', '153.112'),
        ('kea-x-icu', 11, 10, 'i', -1, 'kea', 'kea', '153.112'),
        ('kea-CV-x-icu', 11, 10, 'i', -1, 'kea-CV', 'kea-CV', '153.112'),
        ('khq-x-icu', 11, 10, 'i', -1, 'khq', 'khq', '153.112'),
        ('khq-ML-x-icu', 11, 10, 'i', -1, 'khq-ML', 'khq-ML', '153.112'),
        ('ki-x-icu', 11, 10, 'i', -1, 'ki', 'ki', '153.112'),
        ('ki-KE-x-icu', 11, 10, 'i', -1, 'ki-KE', 'ki-KE', '153.112'),
        ('kk-x-icu', 11, 10, 'i', -1, 'kk', 'kk', '153.112.40'),
        ('kk-KZ-x-icu', 11, 10, 'i', -1, 'kk-KZ', 'kk-KZ', '153.112.40'),
        ('kkj-x-icu', 11, 10, 'i', -1, 'kkj', 'kkj', '153.112'),
        ('kkj-CM-x-icu', 11, 10, 'i', -1, 'kkj-CM', 'kkj-CM', '153.112'),
        ('kl-x-icu', 11, 10, 'i', -1, 'kl', 'kl', '153.112.40'),
        ('kl-GL-x-icu', 11, 10, 'i', -1, 'kl-GL', 'kl-GL', '153.112.40'),
        ('kln-x-icu', 11, 10, 'i', -1, 'kln', 'kln', '153.112'),
        ('kln-KE-x-icu', 11, 10, 'i', -1, 'kln-KE', 'kln-KE', '153.112'),
        ('km-x-icu', 11, 10, 'i', -1, 'km', 'km', '153.112.40'),
        ('km-KH-x-icu', 11, 10, 'i', -1, 'km-KH', 'km-KH', '153.112.40'),
        ('kn-x-icu', 11, 10, 'i', -1, 'kn', 'kn', '153.112.40'),
        ('kn-IN-x-icu', 11, 10, 'i', -1, 'kn-IN', 'kn-IN', '153.112.40'),
        ('ko-x-icu', 11, 10, 'i', -1, 'ko', 'ko', '153.112.40'),
        ('ko-KP-x-icu', 11, 10, 'i', -1, 'ko-KP', 'ko-KP', '153.112.40'),
        ('ko-KR-x-icu', 11, 10, 'i', -1, 'ko-KR', 'ko-KR', '153.112.40'),
        ('kok-x-icu', 11, 10, 'i', -1, 'kok', 'kok', '153.112.40'),
        ('kok-IN-x-icu', 11, 10, 'i', -1, 'kok-IN', 'kok-IN', '153.112.40'),
        ('ks-x-icu', 11, 10, 'i', -1, 'ks', 'ks', '153.112'),
        ('ks-Arab-x-icu', 11, 10, 'i', -1, 'ks-Arab', 'ks-Arab', '153.112'),
        ('ks-Arab-IN-x-icu', 11, 10, 'i', -1, 'ks-Arab-IN', 'ks-Arab-IN', '153.112'),
        ('ksb-x-icu', 11, 10, 'i', -1, 'ksb', 'ksb', '153.112'),
        ('ksb-TZ-x-icu', 11, 10, 'i', -1, 'ksb-TZ', 'ksb-TZ', '153.112'),
        ('ksf-x-icu', 11, 10, 'i', -1, 'ksf', 'ksf', '153.112'),
        ('ksf-CM-x-icu', 11, 10, 'i', -1, 'ksf-CM', 'ksf-CM', '153.112'),
        ('ksh-x-icu', 11, 10, 'i', -1, 'ksh', 'ksh', '153.112'),
        ('ksh-DE-x-icu', 11, 10, 'i', -1, 'ksh-DE', 'ksh-DE', '153.112'),
        ('ku-x-icu', 11, 10, 'i', -1, 'ku', 'ku', '153.112.40'),
        ('ku-TR-x-icu', 11, 10, 'i', -1, 'ku-TR', 'ku-TR', '153.112.40'),
        ('kw-x-icu', 11, 10, 'i', -1, 'kw', 'kw', '153.112'),
        ('kw-GB-x-icu', 11, 10, 'i', -1, 'kw-GB', 'kw-GB', '153.112'),
        ('ky-x-icu', 11, 10, 'i', -1, 'ky', 'ky', '153.112.40'),
        ('ky-KG-x-icu', 11, 10, 'i', -1, 'ky-KG', 'ky-KG', '153.112.40'),
        ('lag-x-icu', 11, 10, 'i', -1, 'lag', 'lag', '153.112'),
        ('lag-TZ-x-icu', 11, 10, 'i', -1, 'lag-TZ', 'lag-TZ', '153.112'),
        ('lb-x-icu', 11, 10, 'i', -1, 'lb', 'lb', '153.112'),
        ('lb-LU-x-icu', 11, 10, 'i', -1, 'lb-LU', 'lb-LU', '153.112'),
        ('lg-x-icu', 11, 10, 'i', -1, 'lg', 'lg', '153.112'),
        ('lg-UG-x-icu', 11, 10, 'i', -1, 'lg-UG', 'lg-UG', '153.112'),
        ('lkt-x-icu', 11, 10, 'i', -1, 'lkt', 'lkt', '153.112.40'),
        ('lkt-US-x-icu', 11, 10, 'i', -1, 'lkt-US', 'lkt-US', '153.112.40'),
        ('ln-x-icu', 11, 10, 'i', -1, 'ln', 'ln', '153.112.40'),
        ('ln-AO-x-icu', 11, 10, 'i', -1, 'ln-AO', 'ln-AO', '153.112.40'),
        ('ln-CD-x-icu', 11, 10, 'i', -1, 'ln-CD', 'ln-CD', '153.112.40'),
        ('ln-CF-x-icu', 11, 10, 'i', -1, 'ln-CF', 'ln-CF', '153.112.40'),
        ('ln-CG-x-icu', 11, 10, 'i', -1, 'ln-CG', 'ln-CG', '153.112.40'),
        ('lo-x-icu', 11, 10, 'i', -1, 'lo', 'lo', '153.112.40'),
        ('lo-LA-x-icu', 11, 10, 'i', -1, 'lo-LA', 'lo-LA', '153.112.40'),
        ('lrc-x-icu', 11, 10, 'i', -1, 'lrc', 'lrc', '153.112'),
        ('lrc-IQ-x-icu', 11, 10, 'i', -1, 'lrc-IQ', 'lrc-IQ', '153.112'),
        ('lrc-IR-x-icu', 11, 10, 'i', -1, 'lrc-IR', 'lrc-IR', '153.112'),
        ('lt-x-icu', 11, 10, 'i', -1, 'lt', 'lt', '153.112.40'),
        ('lt-LT-x-icu', 11, 10, 'i', -1, 'lt-LT', 'lt-LT', '153.112.40'),
        ('lu-x-icu', 11, 10, 'i', -1, 'lu', 'lu', '153.112'),
        ('lu-CD-x-icu', 11, 10, 'i', -1, 'lu-CD', 'lu-CD', '153.112'),
        ('luo-x-icu', 11, 10, 'i', -1, 'luo', 'luo', '153.112'),
        ('luo-KE-x-icu', 11, 10, 'i', -1, 'luo-KE', 'luo-KE', '153.112'),
        ('luy-x-icu', 11, 10, 'i', -1, 'luy', 'luy', '153.112'),
        ('luy-KE-x-icu', 11, 10, 'i', -1, 'luy-KE', 'luy-KE', '153.112'),
        ('lv-x-icu', 11, 10, 'i', -1, 'lv', 'lv', '153.112.40'),
        ('lv-LV-x-icu', 11, 10, 'i', -1, 'lv-LV', 'lv-LV', '153.112.40'),
        ('mai-x-icu', 11, 10, 'i', -1, 'mai', 'mai', '153.112'),
        ('mai-IN-x-icu', 11, 10, 'i', -1, 'mai-IN', 'mai-IN', '153.112'),
        ('mas-x-icu', 11, 10, 'i', -1, 'mas', 'mas', '153.112'),
        ('mas-KE-x-icu', 11, 10, 'i', -1, 'mas-KE', 'mas-KE', '153.112'),
        ('mas-TZ-x-icu', 11, 10, 'i', -1, 'mas-TZ', 'mas-TZ', '153.112'),
        ('mer-x-icu', 11, 10, 'i', -1, 'mer', 'mer', '153.112'),
        ('mer-KE-x-icu', 11, 10, 'i', -1, 'mer-KE', 'mer-KE', '153.112'),
        ('mfe-x-icu', 11, 10, 'i', -1, 'mfe', 'mfe', '153.112'),
        ('mfe-MU-x-icu', 11, 10, 'i', -1, 'mfe-MU', 'mfe-MU', '153.112'),
        ('mg-x-icu', 11, 10, 'i', -1, 'mg', 'mg', '153.112'),
        ('mg-MG-x-icu', 11, 10, 'i', -1, 'mg-MG', 'mg-MG', '153.112'),
        ('mgh-x-icu', 11, 10, 'i', -1, 'mgh', 'mgh', '153.112'),
        ('mgh-MZ-x-icu', 11, 10, 'i', -1, 'mgh-MZ', 'mgh-MZ', '153.112'),
        ('mgo-x-icu', 11, 10, 'i', -1, 'mgo', 'mgo', '153.112'),
        ('mgo-CM-x-icu', 11, 10, 'i', -1, 'mgo-CM', 'mgo-CM', '153.112'),
        ('mi-x-icu', 11, 10, 'i', -1, 'mi', 'mi', '153.112'),
        ('mi-NZ-x-icu', 11, 10, 'i', -1, 'mi-NZ', 'mi-NZ', '153.112'),
        ('mk-x-icu', 11, 10, 'i', -1, 'mk', 'mk', '153.112.40'),
        ('mk-MK-x-icu', 11, 10, 'i', -1, 'mk-MK', 'mk-MK', '153.112.40'),
        ('ml-x-icu', 11, 10, 'i', -1, 'ml', 'ml', '153.112.40'),
        ('ml-IN-x-icu', 11, 10, 'i', -1, 'ml-IN', 'ml-IN', '153.112.40'),
        ('mn-x-icu', 11, 10, 'i', -1, 'mn', 'mn', '153.112.40'),
        ('mn-MN-x-icu', 11, 10, 'i', -1, 'mn-MN', 'mn-MN', '153.112.40'),
        ('mni-x-icu', 11, 10, 'i', -1, 'mni', 'mni', '153.112'),
        ('mni-Beng-x-icu', 11, 10, 'i', -1, 'mni-Beng', 'mni-Beng', '153.112'),
        ('mni-Beng-IN-x-icu', 11, 10, 'i', -1, 'mni-Beng-IN', 'mni-Beng-IN', '153.112'),
        ('mr-x-icu', 11, 10, 'i', -1, 'mr', 'mr', '153.112.40'),
        ('mr-IN-x-icu', 11, 10, 'i', -1, 'mr-IN', 'mr-IN', '153.112.40'),
        ('ms-x-icu', 11, 10, 'i', -1, 'ms', 'ms', '153.112'),
        ('ms-BN-x-icu', 11, 10, 'i', -1, 'ms-BN', 'ms-BN', '153.112'),
        ('ms-ID-x-icu', 11, 10, 'i', -1, 'ms-ID', 'ms-ID', '153.112'),
        ('ms-MY-x-icu', 11, 10, 'i', -1, 'ms-MY', 'ms-MY', '153.112'),
        ('ms-SG-x-icu', 11, 10, 'i', -1, 'ms-SG', 'ms-SG', '153.112'),
        ('mt-x-icu', 11, 10, 'i', -1, 'mt', 'mt', '153.112.40'),
        ('mt-MT-x-icu', 11, 10, 'i', -1, 'mt-MT', 'mt-MT', '153.112.40'),
        ('mua-x-icu', 11, 10, 'i', -1, 'mua', 'mua', '153.112'),
        ('mua-CM-x-icu', 11, 10, 'i', -1, 'mua-CM', 'mua-CM', '153.112'),
        ('my-x-icu', 11, 10, 'i', -1, 'my', 'my', '153.112.40'),
        ('my-MM-x-icu', 11, 10, 'i', -1, 'my-MM', 'my-MM', '153.112.40'),
        ('mzn-x-icu', 11, 10, 'i', -1, 'mzn', 'mzn', '153.112'),
        ('mzn-IR-x-icu', 11, 10, 'i', -1, 'mzn-IR', 'mzn-IR', '153.112'),
        ('naq-x-icu', 11, 10, 'i', -1, 'naq', 'naq', '153.112'),
        ('naq-NA-x-icu', 11, 10, 'i', -1, 'naq-NA', 'naq-NA', '153.112'),
        ('nb-x-icu', 11, 10, 'i', -1, 'nb', 'nb', '153.112.40'),
        ('nb-NO-x-icu', 11, 10, 'i', -1, 'nb-NO', 'nb-NO', '153.112.40'),
        ('nb-SJ-x-icu', 11, 10, 'i', -1, 'nb-SJ', 'nb-SJ', '153.112.40'),
        ('nd-x-icu', 11, 10, 'i', -1, 'nd', 'nd', '153.112'),
        ('nd-ZW-x-icu', 11, 10, 'i', -1, 'nd-ZW', 'nd-ZW', '153.112'),
        ('ne-x-icu', 11, 10, 'i', -1, 'ne', 'ne', '153.112.40'),
        ('ne-IN-x-icu', 11, 10, 'i', -1, 'ne-IN', 'ne-IN', '153.112.40'),
        ('ne-NP-x-icu', 11, 10, 'i', -1, 'ne-NP', 'ne-NP', '153.112.40'),
        ('nl-x-icu', 11, 10, 'i', -1, 'nl', 'nl', '153.112'),
        ('nl-AW-x-icu', 11, 10, 'i', -1, 'nl-AW', 'nl-AW', '153.112'),
        ('nl-BE-x-icu', 11, 10, 'i', -1, 'nl-BE', 'nl-BE', '153.112'),
        ('nl-BQ-x-icu', 11, 10, 'i', -1, 'nl-BQ', 'nl-BQ', '153.112'),
        ('nl-CW-x-icu', 11, 10, 'i', -1, 'nl-CW', 'nl-CW', '153.112'),
        ('nl-NL-x-icu', 11, 10, 'i', -1, 'nl-NL', 'nl-NL', '153.112'),
        ('nl-SR-x-icu', 11, 10, 'i', -1, 'nl-SR', 'nl-SR', '153.112'),
        ('nl-SX-x-icu', 11, 10, 'i', -1, 'nl-SX', 'nl-SX', '153.112'),
        ('nmg-x-icu', 11, 10, 'i', -1, 'nmg', 'nmg', '153.112'),
        ('nmg-CM-x-icu', 11, 10, 'i', -1, 'nmg-CM', 'nmg-CM', '153.112'),
        ('nn-x-icu', 11, 10, 'i', -1, 'nn', 'nn', '153.112.40'),
        ('nn-NO-x-icu', 11, 10, 'i', -1, 'nn-NO', 'nn-NO', '153.112.40'),
        ('nnh-x-icu', 11, 10, 'i', -1, 'nnh', 'nnh', '153.112'),
        ('nnh-CM-x-icu', 11, 10, 'i', -1, 'nnh-CM', 'nnh-CM', '153.112'),
        ('no-x-icu', 11, 10, 'i', -1, 'no', 'no', '153.112.40'),
        ('nus-x-icu', 11, 10, 'i', -1, 'nus', 'nus', '153.112'),
        ('nus-SS-x-icu', 11, 10, 'i', -1, 'nus-SS', 'nus-SS', '153.112'),
        ('nyn-x-icu', 11, 10, 'i', -1, 'nyn', 'nyn', '153.112'),
        ('nyn-UG-x-icu', 11, 10, 'i', -1, 'nyn-UG', 'nyn-UG', '153.112'),
        ('om-x-icu', 11, 10, 'i', -1, 'om', 'om', '153.112.40'),
        ('om-ET-x-icu', 11, 10, 'i', -1, 'om-ET', 'om-ET', '153.112.40'),
        ('om-KE-x-icu', 11, 10, 'i', -1, 'om-KE', 'om-KE', '153.112.40'),
        ('or-x-icu', 11, 10, 'i', -1, 'or', 'or', '153.112.40'),
        ('or-IN-x-icu', 11, 10, 'i', -1, 'or-IN', 'or-IN', '153.112.40'),
        ('os-x-icu', 11, 10, 'i', -1, 'os', 'os', '153.112'),
        ('os-GE-x-icu', 11, 10, 'i', -1, 'os-GE', 'os-GE', '153.112'),
        ('os-RU-x-icu', 11, 10, 'i', -1, 'os-RU', 'os-RU', '153.112'),
        ('pa-x-icu', 11, 10, 'i', -1, 'pa', 'pa', '153.112.40'),
        ('pa-Arab-x-icu', 11, 10, 'i', -1, 'pa-Arab', 'pa-Arab', '153.112.40'),
        ('pa-Arab-PK-x-icu', 11, 10, 'i', -1, 'pa-Arab-PK', 'pa-Arab-PK', '153.112.40'),
        ('pa-Guru-x-icu', 11, 10, 'i', -1, 'pa-Guru', 'pa-Guru', '153.112.40'),
        ('pa-Guru-IN-x-icu', 11, 10, 'i', -1, 'pa-Guru-IN', 'pa-Guru-IN', '153.112.40'),
        ('pcm-x-icu', 11, 10, 'i', -1, 'pcm', 'pcm', '153.112'),
        ('pcm-NG-x-icu', 11, 10, 'i', -1, 'pcm-NG', 'pcm-NG', '153.112'),
        ('pl-x-icu', 11, 10, 'i', -1, 'pl', 'pl', '153.112.40'),
        ('pl-PL-x-icu', 11, 10, 'i', -1, 'pl-PL', 'pl-PL', '153.112.40'),
        ('ps-x-icu', 11, 10, 'i', -1, 'ps', 'ps', '153.112.40'),
        ('ps-AF-x-icu', 11, 10, 'i', -1, 'ps-AF', 'ps-AF', '153.112.40'),
        ('ps-PK-x-icu', 11, 10, 'i', -1, 'ps-PK', 'ps-PK', '153.112.40'),
        ('pt-x-icu', 11, 10, 'i', -1, 'pt', 'pt', '153.112'),
        ('pt-AO-x-icu', 11, 10, 'i', -1, 'pt-AO', 'pt-AO', '153.112'),
        ('pt-BR-x-icu', 11, 10, 'i', -1, 'pt-BR', 'pt-BR', '153.112'),
        ('pt-CH-x-icu', 11, 10, 'i', -1, 'pt-CH', 'pt-CH', '153.112'),
        ('pt-CV-x-icu', 11, 10, 'i', -1, 'pt-CV', 'pt-CV', '153.112'),
        ('pt-GQ-x-icu', 11, 10, 'i', -1, 'pt-GQ', 'pt-GQ', '153.112'),
        ('pt-GW-x-icu', 11, 10, 'i', -1, 'pt-GW', 'pt-GW', '153.112'),
        ('pt-LU-x-icu', 11, 10, 'i', -1, 'pt-LU', 'pt-LU', '153.112'),
        ('pt-MO-x-icu', 11, 10, 'i', -1, 'pt-MO', 'pt-MO', '153.112'),
        ('pt-MZ-x-icu', 11, 10, 'i', -1, 'pt-MZ', 'pt-MZ', '153.112'),
        ('pt-PT-x-icu', 11, 10, 'i', -1, 'pt-PT', 'pt-PT', '153.112'),
        ('pt-ST-x-icu', 11, 10, 'i', -1, 'pt-ST', 'pt-ST', '153.112'),
        ('pt-TL-x-icu', 11, 10, 'i', -1, 'pt-TL', 'pt-TL', '153.112'),
        ('qu-x-icu', 11, 10, 'i', -1, 'qu', 'qu', '153.112'),
        ('qu-BO-x-icu', 11, 10, 'i', -1, 'qu-BO', 'qu-BO', '153.112'),
        ('qu-EC-x-icu', 11, 10, 'i', -1, 'qu-EC', 'qu-EC', '153.112'),
        ('qu-PE-x-icu', 11, 10, 'i', -1, 'qu-PE', 'qu-PE', '153.112'),
        ('rm-x-icu', 11, 10, 'i', -1, 'rm', 'rm', '153.112'),
        ('rm-CH-x-icu', 11, 10, 'i', -1, 'rm-CH', 'rm-CH', '153.112'),
        ('rn-x-icu', 11, 10, 'i', -1, 'rn', 'rn', '153.112'),
        ('rn-BI-x-icu', 11, 10, 'i', -1, 'rn-BI', 'rn-BI', '153.112'),
        ('ro-x-icu', 11, 10, 'i', -1, 'ro', 'ro', '153.112.40'),
        ('ro-MD-x-icu', 11, 10, 'i', -1, 'ro-MD', 'ro-MD', '153.112.40'),
        ('ro-RO-x-icu', 11, 10, 'i', -1, 'ro-RO', 'ro-RO', '153.112.40'),
        ('rof-x-icu', 11, 10, 'i', -1, 'rof', 'rof', '153.112'),
        ('rof-TZ-x-icu', 11, 10, 'i', -1, 'rof-TZ', 'rof-TZ', '153.112'),
        ('ru-x-icu', 11, 10, 'i', -1, 'ru', 'ru', '153.112.40'),
        ('ru-BY-x-icu', 11, 10, 'i', -1, 'ru-BY', 'ru-BY', '153.112.40'),
        ('ru-KG-x-icu', 11, 10, 'i', -1, 'ru-KG', 'ru-KG', '153.112.40'),
        ('ru-KZ-x-icu', 11, 10, 'i', -1, 'ru-KZ', 'ru-KZ', '153.112.40'),
        ('ru-MD-x-icu', 11, 10, 'i', -1, 'ru-MD', 'ru-MD', '153.112.40'),
        ('ru-RU-x-icu', 11, 10, 'i', -1, 'ru-RU', 'ru-RU', '153.112.40'),
        ('ru-UA-x-icu', 11, 10, 'i', -1, 'ru-UA', 'ru-UA', '153.112.40'),
        ('rw-x-icu', 11, 10, 'i', -1, 'rw', 'rw', '153.112'),
        ('rw-RW-x-icu', 11, 10, 'i', -1, 'rw-RW', 'rw-RW', '153.112'),
        ('rwk-x-icu', 11, 10, 'i', -1, 'rwk', 'rwk', '153.112'),
        ('rwk-TZ-x-icu', 11, 10, 'i', -1, 'rwk-TZ', 'rwk-TZ', '153.112'),
        ('sa-x-icu', 11, 10, 'i', -1, 'sa', 'sa', '153.112'),
        ('sa-IN-x-icu', 11, 10, 'i', -1, 'sa-IN', 'sa-IN', '153.112'),
        ('sah-x-icu', 11, 10, 'i', -1, 'sah', 'sah', '153.112'),
        ('sah-RU-x-icu', 11, 10, 'i', -1, 'sah-RU', 'sah-RU', '153.112'),
        ('saq-x-icu', 11, 10, 'i', -1, 'saq', 'saq', '153.112'),
        ('saq-KE-x-icu', 11, 10, 'i', -1, 'saq-KE', 'saq-KE', '153.112'),
        ('sat-x-icu', 11, 10, 'i', -1, 'sat', 'sat', '153.112'),
        ('sat-Olck-x-icu', 11, 10, 'i', -1, 'sat-Olck', 'sat-Olck', '153.112'),
        ('sat-Olck-IN-x-icu', 11, 10, 'i', -1, 'sat-Olck-IN', 'sat-Olck-IN', '153.112'),
        ('sbp-x-icu', 11, 10, 'i', -1, 'sbp', 'sbp', '153.112'),
        ('sbp-TZ-x-icu', 11, 10, 'i', -1, 'sbp-TZ', 'sbp-TZ', '153.112'),
        ('sc-x-icu', 11, 10, 'i', -1, 'sc', 'sc', '153.112'),
        ('sc-IT-x-icu', 11, 10, 'i', -1, 'sc-IT', 'sc-IT', '153.112'),
        ('sd-x-icu', 11, 10, 'i', -1, 'sd', 'sd', '153.112'),
        ('sd-Arab-x-icu', 11, 10, 'i', -1, 'sd-Arab', 'sd-Arab', '153.112'),
        ('sd-Arab-PK-x-icu', 11, 10, 'i', -1, 'sd-Arab-PK', 'sd-Arab-PK', '153.112'),
        ('sd-Deva-x-icu', 11, 10, 'i', -1, 'sd-Deva', 'sd-Deva', '153.112'),
        ('sd-Deva-IN-x-icu', 11, 10, 'i', -1, 'sd-Deva-IN', 'sd-Deva-IN', '153.112'),
        ('se-x-icu', 11, 10, 'i', -1, 'se', 'se', '153.112.40'),
        ('se-FI-x-icu', 11, 10, 'i', -1, 'se-FI', 'se-FI', '153.112.40'),
        ('se-NO-x-icu', 11, 10, 'i', -1, 'se-NO', 'se-NO', '153.112.40'),
        ('se-SE-x-icu', 11, 10, 'i', -1, 'se-SE', 'se-SE', '153.112.40'),
        ('seh-x-icu', 11, 10, 'i', -1, 'seh', 'seh', '153.112'),
        ('seh-MZ-x-icu', 11, 10, 'i', -1, 'seh-MZ', 'seh-MZ', '153.112'),
        ('ses-x-icu', 11, 10, 'i', -1, 'ses', 'ses', '153.112'),
        ('ses-ML-x-icu', 11, 10, 'i', -1, 'ses-ML', 'ses-ML', '153.112'),
        ('sg-x-icu', 11, 10, 'i', -1, 'sg', 'sg', '153.112'),
        ('sg-CF-x-icu', 11, 10, 'i', -1, 'sg-CF', 'sg-CF', '153.112'),
        ('shi-x-icu', 11, 10, 'i', -1, 'shi', 'shi', '153.112'),
        ('shi-Latn-x-icu', 11, 10, 'i', -1, 'shi-Latn', 'shi-Latn', '153.112'),
        ('shi-Latn-MA-x-icu', 11, 10, 'i', -1, 'shi-Latn-MA', 'shi-Latn-MA', '153.112'),
        ('shi-Tfng-x-icu', 11, 10, 'i', -1, 'shi-Tfng', 'shi-Tfng', '153.112'),
        ('shi-Tfng-MA-x-icu', 11, 10, 'i', -1, 'shi-Tfng-MA', 'shi-Tfng-MA', '153.112'),
        ('si-x-icu', 11, 10, 'i', -1, 'si', 'si', '153.112.40'),
        ('si-LK-x-icu', 11, 10, 'i', -1, 'si-LK', 'si-LK', '153.112.40'),
        ('sk-x-icu', 11, 10, 'i', -1, 'sk', 'sk', '153.112.40'),
        ('sk-SK-x-icu', 11, 10, 'i', -1, 'sk-SK', 'sk-SK', '153.112.40'),
        ('sl-x-icu', 11, 10, 'i', -1, 'sl', 'sl', '153.112.40'),
        ('sl-SI-x-icu', 11, 10, 'i', -1, 'sl-SI', 'sl-SI', '153.112.40'),
        ('smn-x-icu', 11, 10, 'i', -1, 'smn', 'smn', '153.112.40'),
        ('smn-FI-x-icu', 11, 10, 'i', -1, 'smn-FI', 'smn-FI', '153.112.40'),
        ('sn-x-icu', 11, 10, 'i', -1, 'sn', 'sn', '153.112'),
        ('sn-ZW-x-icu', 11, 10, 'i', -1, 'sn-ZW', 'sn-ZW', '153.112'),
        ('so-x-icu', 11, 10, 'i', -1, 'so', 'so', '153.112'),
        ('so-DJ-x-icu', 11, 10, 'i', -1, 'so-DJ', 'so-DJ', '153.112'),
        ('so-ET-x-icu', 11, 10, 'i', -1, 'so-ET', 'so-ET', '153.112'),
        ('so-KE-x-icu', 11, 10, 'i', -1, 'so-KE', 'so-KE', '153.112'),
        ('so-SO-x-icu', 11, 10, 'i', -1, 'so-SO', 'so-SO', '153.112'),
        ('sq-x-icu', 11, 10, 'i', -1, 'sq', 'sq', '153.112.40'),
        ('sq-AL-x-icu', 11, 10, 'i', -1, 'sq-AL', 'sq-AL', '153.112.40'),
        ('sq-MK-x-icu', 11, 10, 'i', -1, 'sq-MK', 'sq-MK', '153.112.40'),
        ('sq-XK-x-icu', 11, 10, 'i', -1, 'sq-XK', 'sq-XK', '153.112.40'),
        ('sr-x-icu', 11, 10, 'i', -1, 'sr', 'sr', '153.112.40'),
        ('sr-Cyrl-x-icu', 11, 10, 'i', -1, 'sr-Cyrl', 'sr-Cyrl', '153.112.40'),
        ('sr-Cyrl-BA-x-icu', 11, 10, 'i', -1, 'sr-Cyrl-BA', 'sr-Cyrl-BA', '153.112.40'),
        ('sr-Cyrl-ME-x-icu', 11, 10, 'i', -1, 'sr-Cyrl-ME', 'sr-Cyrl-ME', '153.112.40'),
        ('sr-Cyrl-RS-x-icu', 11, 10, 'i', -1, 'sr-Cyrl-RS', 'sr-Cyrl-RS', '153.112.40'),
        ('sr-Cyrl-XK-x-icu', 11, 10, 'i', -1, 'sr-Cyrl-XK', 'sr-Cyrl-XK', '153.112.40'),
        ('sr-Latn-x-icu', 11, 10, 'i', -1, 'sr-Latn', 'sr-Latn', '153.112.40'),
        ('sr-Latn-BA-x-icu', 11, 10, 'i', -1, 'sr-Latn-BA', 'sr-Latn-BA', '153.112.40'),
        ('sr-Latn-ME-x-icu', 11, 10, 'i', -1, 'sr-Latn-ME', 'sr-Latn-ME', '153.112.40'),
        ('sr-Latn-RS-x-icu', 11, 10, 'i', -1, 'sr-Latn-RS', 'sr-Latn-RS', '153.112.40'),
        ('sr-Latn-XK-x-icu', 11, 10, 'i', -1, 'sr-Latn-XK', 'sr-Latn-XK', '153.112.40'),
        ('su-x-icu', 11, 10, 'i', -1, 'su', 'su', '153.112'),
        ('su-Latn-x-icu', 11, 10, 'i', -1, 'su-Latn', 'su-Latn', '153.112'),
        ('su-Latn-ID-x-icu', 11, 10, 'i', -1, 'su-Latn-ID', 'su-Latn-ID', '153.112'),
        ('sv-x-icu', 11, 10, 'i', -1, 'sv', 'sv', '153.112.40'),
        ('sv-AX-x-icu', 11, 10, 'i', -1, 'sv-AX', 'sv-AX', '153.112.40'),
        ('sv-FI-x-icu', 11, 10, 'i', -1, 'sv-FI', 'sv-FI', '153.112.40'),
        ('sv-SE-x-icu', 11, 10, 'i', -1, 'sv-SE', 'sv-SE', '153.112.40'),
        ('sw-x-icu', 11, 10, 'i', -1, 'sw', 'sw', '153.112'),
        ('sw-CD-x-icu', 11, 10, 'i', -1, 'sw-CD', 'sw-CD', '153.112'),
        ('sw-KE-x-icu', 11, 10, 'i', -1, 'sw-KE', 'sw-KE', '153.112'),
        ('sw-TZ-x-icu', 11, 10, 'i', -1, 'sw-TZ', 'sw-TZ', '153.112'),
        ('sw-UG-x-icu', 11, 10, 'i', -1, 'sw-UG', 'sw-UG', '153.112'),
        ('ta-x-icu', 11, 10, 'i', -1, 'ta', 'ta', '153.112.40'),
        ('ta-IN-x-icu', 11, 10, 'i', -1, 'ta-IN', 'ta-IN', '153.112.40'),
        ('ta-LK-x-icu', 11, 10, 'i', -1, 'ta-LK', 'ta-LK', '153.112.40'),
        ('ta-MY-x-icu', 11, 10, 'i', -1, 'ta-MY', 'ta-MY', '153.112.40'),
        ('ta-SG-x-icu', 11, 10, 'i', -1, 'ta-SG', 'ta-SG', '153.112.40'),
        ('te-x-icu', 11, 10, 'i', -1, 'te', 'te', '153.112.40'),
        ('te-IN-x-icu', 11, 10, 'i', -1, 'te-IN', 'te-IN', '153.112.40'),
        ('teo-x-icu', 11, 10, 'i', -1, 'teo', 'teo', '153.112'),
        ('teo-KE-x-icu', 11, 10, 'i', -1, 'teo-KE', 'teo-KE', '153.112'),
        ('teo-UG-x-icu', 11, 10, 'i', -1, 'teo-UG', 'teo-UG', '153.112'),
        ('tg-x-icu', 11, 10, 'i', -1, 'tg', 'tg', '153.112'),
        ('tg-TJ-x-icu', 11, 10, 'i', -1, 'tg-TJ', 'tg-TJ', '153.112'),
        ('th-x-icu', 11, 10, 'i', -1, 'th', 'th', '153.112.40'),
        ('th-TH-x-icu', 11, 10, 'i', -1, 'th-TH', 'th-TH', '153.112.40'),
        ('ti-x-icu', 11, 10, 'i', -1, 'ti', 'ti', '153.112'),
        ('ti-ER-x-icu', 11, 10, 'i', -1, 'ti-ER', 'ti-ER', '153.112'),
        ('ti-ET-x-icu', 11, 10, 'i', -1, 'ti-ET', 'ti-ET', '153.112'),
        ('tk-x-icu', 11, 10, 'i', -1, 'tk', 'tk', '153.112.40'),
        ('tk-TM-x-icu', 11, 10, 'i', -1, 'tk-TM', 'tk-TM', '153.112.40'),
        ('to-x-icu', 11, 10, 'i', -1, 'to', 'to', '153.112.40'),
        ('to-TO-x-icu', 11, 10, 'i', -1, 'to-TO', 'to-TO', '153.112.40'),
        ('tr-x-icu', 11, 10, 'i', -1, 'tr', 'tr', '153.112.40'),
        ('tr-CY-x-icu', 11, 10, 'i', -1, 'tr-CY', 'tr-CY', '153.112.40'),
        ('tr-TR-x-icu', 11, 10, 'i', -1, 'tr-TR', 'tr-TR', '153.112.40'),
        ('tt-x-icu', 11, 10, 'i', -1, 'tt', 'tt', '153.112'),
        ('tt-RU-x-icu', 11, 10, 'i', -1, 'tt-RU', 'tt-RU', '153.112'),
        ('twq-x-icu', 11, 10, 'i', -1, 'twq', 'twq', '153.112'),
        ('twq-NE-x-icu', 11, 10, 'i', -1, 'twq-NE', 'twq-NE', '153.112'),
        ('tzm-x-icu', 11, 10, 'i', -1, 'tzm', 'tzm', '153.112'),
        ('tzm-MA-x-icu', 11, 10, 'i', -1, 'tzm-MA', 'tzm-MA', '153.112'),
        ('ug-x-icu', 11, 10, 'i', -1, 'ug', 'ug', '153.112.40'),
        ('ug-CN-x-icu', 11, 10, 'i', -1, 'ug-CN', 'ug-CN', '153.112.40'),
        ('uk-x-icu', 11, 10, 'i', -1, 'uk', 'uk', '153.112.40'),
        ('uk-UA-x-icu', 11, 10, 'i', -1, 'uk-UA', 'uk-UA', '153.112.40'),
        ('ur-x-icu', 11, 10, 'i', -1, 'ur', 'ur', '153.112.40'),
        ('ur-IN-x-icu', 11, 10, 'i', -1, 'ur-IN', 'ur-IN', '153.112.40'),
        ('ur-PK-x-icu', 11, 10, 'i', -1, 'ur-PK', 'ur-PK', '153.112.40'),
        ('uz-x-icu', 11, 10, 'i', -1, 'uz', 'uz', '153.112.40'),
        ('uz-Arab-x-icu', 11, 10, 'i', -1, 'uz-Arab', 'uz-Arab', '153.112.40'),
        ('uz-Arab-AF-x-icu', 11, 10, 'i', -1, 'uz-Arab-AF', 'uz-Arab-AF', '153.112.40'),
        ('uz-Cyrl-x-icu', 11, 10, 'i', -1, 'uz-Cyrl', 'uz-Cyrl', '153.112.40'),
        ('uz-Cyrl-UZ-x-icu', 11, 10, 'i', -1, 'uz-Cyrl-UZ', 'uz-Cyrl-UZ', '153.112.40'),
        ('uz-Latn-x-icu', 11, 10, 'i', -1, 'uz-Latn', 'uz-Latn', '153.112.40'),
        ('uz-Latn-UZ-x-icu', 11, 10, 'i', -1, 'uz-Latn-UZ', 'uz-Latn-UZ', '153.112.40'),
        ('vai-x-icu', 11, 10, 'i', -1, 'vai', 'vai', '153.112'),
        ('vai-Latn-x-icu', 11, 10, 'i', -1, 'vai-Latn', 'vai-Latn', '153.112'),
        ('vai-Latn-LR-x-icu', 11, 10, 'i', -1, 'vai-Latn-LR', 'vai-Latn-LR', '153.112'),
        ('vai-Vaii-x-icu', 11, 10, 'i', -1, 'vai-Vaii', 'vai-Vaii', '153.112'),
        ('vai-Vaii-LR-x-icu', 11, 10, 'i', -1, 'vai-Vaii-LR', 'vai-Vaii-LR', '153.112'),
        ('vi-x-icu', 11, 10, 'i', -1, 'vi', 'vi', '153.112.40'),
        ('vi-VN-x-icu', 11, 10, 'i', -1, 'vi-VN', 'vi-VN', '153.112.40'),
        ('vun-x-icu', 11, 10, 'i', -1, 'vun', 'vun', '153.112'),
        ('vun-TZ-x-icu', 11, 10, 'i', -1, 'vun-TZ', 'vun-TZ', '153.112'),
        ('wae-x-icu', 11, 10, 'i', -1, 'wae', 'wae', '153.112'),
        ('wae-CH-x-icu', 11, 10, 'i', -1, 'wae-CH', 'wae-CH', '153.112'),
        ('wo-x-icu', 11, 10, 'i', -1, 'wo', 'wo', '153.112.40'),
        ('wo-SN-x-icu', 11, 10, 'i', -1, 'wo-SN', 'wo-SN', '153.112.40'),
        ('xh-x-icu', 11, 10, 'i', -1, 'xh', 'xh', '153.112'),
        ('xh-ZA-x-icu', 11, 10, 'i', -1, 'xh-ZA', 'xh-ZA', '153.112'),
        ('xog-x-icu', 11, 10, 'i', -1, 'xog', 'xog', '153.112'),
        ('xog-UG-x-icu', 11, 10, 'i', -1, 'xog-UG', 'xog-UG', '153.112'),
        ('yav-x-icu', 11, 10, 'i', -1, 'yav', 'yav', '153.112'),
        ('yav-CM-x-icu', 11, 10, 'i', -1, 'yav-CM', 'yav-CM', '153.112'),
        ('yi-x-icu', 11, 10, 'i', -1, 'yi', 'yi', '153.112.40'),
        ('yi-001-x-icu', 11, 10, 'i', -1, 'yi-001', 'yi-001', '153.112.40'),
        ('yo-x-icu', 11, 10, 'i', -1, 'yo', 'yo', '153.112.40'),
        ('yo-BJ-x-icu', 11, 10, 'i', -1, 'yo-BJ', 'yo-BJ', '153.112.40'),
        ('yo-NG-x-icu', 11, 10, 'i', -1, 'yo-NG', 'yo-NG', '153.112.40'),
        ('yue-x-icu', 11, 10, 'i', -1, 'yue', 'yue', '153.112.40'),
        ('yue-Hans-x-icu', 11, 10, 'i', -1, 'yue-Hans', 'yue-Hans', '153.112.40'),
        ('yue-Hans-CN-x-icu', 11, 10, 'i', -1, 'yue-Hans-CN', 'yue-Hans-CN', '153.112.40'),
        ('yue-Hant-x-icu', 11, 10, 'i', -1, 'yue-Hant', 'yue-Hant', '153.112.40'),
        ('yue-Hant-HK-x-icu', 11, 10, 'i', -1, 'yue-Hant-HK', 'yue-Hant-HK', '153.112.40'),
        ('zgh-x-icu', 11, 10, 'i', -1, 'zgh', 'zgh', '153.112'),
        ('zgh-MA-x-icu', 11, 10, 'i', -1, 'zgh-MA', 'zgh-MA', '153.112'),
        ('zh-x-icu', 11, 10, 'i', -1, 'zh', 'zh', '153.112.40'),
        ('zh-Hans-x-icu', 11, 10, 'i', -1, 'zh-Hans', 'zh-Hans', '153.112.40'),
        ('zh-Hans-CN-x-icu', 11, 10, 'i', -1, 'zh-Hans-CN', 'zh-Hans-CN', '153.112.40'),
        ('zh-Hans-HK-x-icu', 11, 10, 'i', -1, 'zh-Hans-HK', 'zh-Hans-HK', '153.112.40'),
        ('zh-Hans-MO-x-icu', 11, 10, 'i', -1, 'zh-Hans-MO', 'zh-Hans-MO', '153.112.40'),
        ('zh-Hans-SG-x-icu', 11, 10, 'i', -1, 'zh-Hans-SG', 'zh-Hans-SG', '153.112.40'),
        ('zh-Hant-x-icu', 11, 10, 'i', -1, 'zh-Hant', 'zh-Hant', '153.112.40'),
        ('zh-Hant-HK-x-icu', 11, 10, 'i', -1, 'zh-Hant-HK', 'zh-Hant-HK', '153.112.40'),
        ('zh-Hant-MO-x-icu', 11, 10, 'i', -1, 'zh-Hant-MO', 'zh-Hant-MO', '153.112.40'),
        ('zh-Hant-TW-x-icu', 11, 10, 'i', -1, 'zh-Hant-TW', 'zh-Hant-TW', '153.112.40'),
        ('zu-x-icu', 11, 10, 'i', -1, 'zu', 'zu', '153.112'),
        ('zu-ZA-x-icu', 11, 10, 'i', -1, 'zu-ZA', 'zu-ZA', '153.112')
    ) AS updated_values (
      collname, collnamespace, collowner, collprovider,
      collencoding, collcollate, collctype, collversion
    )
    WHERE pg_catalog.pg_collation.collname = updated_values.collname
    AND pg_catalog.pg_collation.collencoding = updated_values.collencoding
    AND pg_catalog.pg_collation.collnamespace = updated_values.collnamespace;

    -- Insert new collations.
    WITH descr_insert_oids(pg_coll_oid) AS (
      INSERT INTO pg_catalog.pg_collation (
        collname, collnamespace, collowner, collprovider,
        collencoding, collcollate, collctype, collversion
      ) VALUES
        ('doi-x-icu', 11, 10, 'i', -1, 'doi', 'doi', '153.112'),
        ('doi-IN-x-icu', 11, 10, 'i', -1, 'doi-IN', 'doi-IN', '153.112'),
        ('no-x-icu', 11, 10, 'i', -1, 'no', 'no', '153.112.40'),
        ('sa-x-icu', 11, 10, 'i', -1, 'sa', 'sa', '153.112'),
        ('sa-IN-x-icu', 11, 10, 'i', -1, 'sa-IN', 'sa-IN', '153.112'),
        ('sc-x-icu', 11, 10, 'i', -1, 'sc', 'sc', '153.112'),
        ('sc-IT-x-icu', 11, 10, 'i', -1, 'sc-IT', 'sc-IT', '153.112')
      RETURNING oid
    ), tmp_descr (row_number, description) AS (
      -- Some collations do not have a matching description. We need to correctly match
      -- a collation with its corresponding description. Use row_number to track the collation
      -- list order.
      VALUES
        (1, 'Dogri'),
        (2, 'Dogri (India)'),
        (3, 'Norwegian'),
        (4, 'Sanskrit'),
        (5, 'Sanskrit (India)'),
        (6, 'Sardinian'),
        (7, 'Sardinian (Italy)')
    )
    -- Populate pg_description table using the auto-generated OIDs for newly inserted collations.
    -- Use collation list order as the link to properly match collations with descriptions.
    INSERT INTO pg_catalog.pg_description (
      objoid, classoid, objsubid, description
    ) SELECT o.pg_coll_oid, 'pg_collation'::regclass, 0, d.description
      FROM (
        SELECT
          ROW_NUMBER() OVER (ORDER BY pg_coll_oid) AS row_number,
          pg_coll_oid
        FROM descr_insert_oids
      ) o
      INNER JOIN tmp_descr d ON o.row_number = d.row_number;

  END IF;
END $$;
